package com.zanxiang.game.module.manage.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.sd4324530.jtuple.Tuple3;
import com.zanxiang.erp.security.annotation.PreAuthorize;
import com.zanxiang.game.module.manage.pojo.params.GameGiftPackLinkAddParam;
import com.zanxiang.game.module.manage.pojo.params.GameGiftPackLinkListParam;
import com.zanxiang.game.module.manage.pojo.params.GameGiftPackLinkUpdateParam;
import com.zanxiang.game.module.manage.pojo.vo.GameGiftPackLinkVO;
import com.zanxiang.game.module.manage.service.IGameGiftPackConfigService;
import com.zanxiang.game.module.manage.service.IGameGiftPackLinkService;
import com.zanxiang.module.util.pojo.ResultVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @author : lingfeng
 * @time : 2024-10-31
 * @description : 游戏礼包发码器
 */
@Slf4j
@Api(tags = {"游戏礼包发码器"})
@RestController
@RequestMapping("/game/gift/pack")
public class GameGiftPackCodeController {

    @Autowired
    private IGameGiftPackLinkService gameGiftPackLinkService;

    @Autowired
    private IGameGiftPackConfigService gameGiftPackConfigService;

    @ApiOperation(value = "获取发码器配置")
    @GetMapping(value = "/config/list")
    @PreAuthorize(permissionKey = "manage:giftPack:configList")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = List.class)})
    public ResultVO<List<Tuple3<Long, List<Long>, Map<String, String>>>> getGameGiftPackConfig() {
        return ResultVO.ok(gameGiftPackConfigService.getGameGiftPackConfig());
    }

    @ApiOperation(value = "查询礼包码链接列表")
    @PostMapping(value = "/link/list")
    @PreAuthorize(permissionKey = "manage:giftPack:linkList")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameGiftPackLinkVO.class)})
    public ResultVO<IPage<GameGiftPackLinkVO>> linkList(@Validated @RequestBody GameGiftPackLinkListParam param) {
        return ResultVO.ok(gameGiftPackLinkService.list(param));
    }

    @ApiOperation(value = "更新礼包码链接")
    @PostMapping(value = "/link/update")
    @PreAuthorize(permissionKey = "manage:giftPack:linkUpdate")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> updateGiftPackLin(@Validated @RequestBody GameGiftPackLinkUpdateParam param) {
        return ResultVO.ok(gameGiftPackLinkService.updateGiftPackLin(param));
    }

    @ApiOperation(value = "删除礼包码链接")
    @DeleteMapping(value = "/link/delete")
    @PreAuthorize(permissionKey = "manage:giftPack:linkDelete")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> deleteById(@RequestParam Long id) {
        return ResultVO.ok(gameGiftPackLinkService.deleteById(id));
    }

    @ApiOperation(value = "添加礼包码链接")
    @PostMapping(value = "/link/add")
    @PreAuthorize(permissionKey = "manage:giftPack:linkAdd")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> addGiftPackLin(@Validated @RequestBody GameGiftPackLinkAddParam param) {
        return ResultVO.ok(gameGiftPackLinkService.addGiftPackLin(param));
    }
}
