package com.zanxiang.game.module.manage.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.sd4324530.jtuple.Tuple3;
import com.zanxiang.game.module.manage.service.IGameGiftPackConfigService;
import com.zanxiang.game.module.mybatis.entity.GameGiftPackConfig;
import com.zanxiang.game.module.mybatis.mapper.GameGiftPackConfigMapper;
import com.zanxiang.module.util.JsonUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @author : lingfeng
 * @time : 2022-06-22
 * @description : 游戏礼包码配置
 */
@Slf4j
@Service
public class GameGiftPackConfigServiceImpl extends ServiceImpl<GameGiftPackConfigMapper, GameGiftPackConfig> implements IGameGiftPackConfigService {

    @Override
    public List<Tuple3<Long, List<Long>, Map<String, String>>> getGameGiftPackConfig() {
        List<GameGiftPackConfig> gameGiftPackConfigList = super.list();
        if (CollectionUtils.isEmpty(gameGiftPackConfigList)) {
            return Collections.emptyList();
        }
        List<Tuple3<Long, List<Long>, Map<String, String>>> list = new ArrayList<>();
        gameGiftPackConfigList.forEach(config -> {
            String gameIds = config.getGameIds();
            String codeTypeConfig = config.getCodeTypeConfig();
            if (StringUtils.isAnyEmpty(gameIds, codeTypeConfig)) {
                return;
            }
            List<Long> gameIdList = Arrays.stream(gameIds.split(",")).distinct()
                    .map(Long::valueOf).collect(Collectors.toList());
            Map<String, String> codeTypeMap = JsonUtil.toMap(codeTypeConfig, Map.class, String.class);
            list.add(Tuple3.with(config.getSuperGameId(), gameIdList, codeTypeMap));
        });
        return list;
    }
}




